@@ -18,14 +18,16 @@ import yaml
 
 from tqdm import tqdm
 
-from s3prl.nn import S3PRLUpstream, Featurizer
+from s3prl.nn import Featurizer
 
 import s3prl_vc.models
+from s3prl_vc.upstream.interface import get_upstream
 from s3prl_vc.datasets.datasets import AudioSCPMelDataset, AudioMelDataset
 from s3prl_vc.utils import read_hdf5, write_hdf5
 from s3prl_vc.utils.data import pad_list
 from s3prl_vc.utils.plot import plot_generated_and_ref_2d, plot_1d
 from s3prl_vc.vocoder import Vocoder
+from s3prl_vc.vocoder.griffin_lim import Spectrogram2Waveform
 
 
 def main():
@@ -78,9 +80,7 @@ def main():
         "--feat_type",
         type=str,
         default="feats",
-        help=(
-            "feature type. this is used as key name to read h5 featyre files. "
-        ),
+        help=("feature type. this is used as key name to read h5 featyre files. "),
     )
     parser.add_argument(
         "--verbose",
@@ -142,26 +142,47 @@ def main():
 
     # get dataset
     if args.scp is not None:
-        dataset = AudioSCPMelDataset(
-            args.scp,
-            config,
-            return_utt_id=True,
-        )
+        if config.get("use_f0", False):
+            dataset = AudioSCPMelDataset(
+                config,
+                args.scp,
+                extract_f0=config.get("use_f0", False),
+                f0_extractor=config.get("f0_extractor", "world"),
+                f0_min=read_hdf5(args.trg_stats, "f0_min"),  # for world f0 extraction
+                f0_max=read_hdf5(args.trg_stats, "f0_max"),  # for world f0 extraction
+                log_f0=config.get("log_f0", True),
+                f0_normalize=config.get("f0_normalize", False),
+                f0_mean=read_hdf5(
+                    args.trg_stats, "lf0_mean"
+                ),  # for speaker normalization
+                f0_scale=read_hdf5(
+                    args.trg_stats, "lf0_scale"
+                ),  # for speaker normalization
+                return_utt_id=True,
+            )
+        else:
+            dataset = AudioSCPMelDataset(
+                config,
+                args.scp,
+                return_utt_id=True,
+            )
     else:
         dataset = AudioMelDataset(
-            args.wavdir,
             config,
+            args.wavdir,
             return_utt_id=True,
         )
-        
+
     logging.info(f"The number of features to be decoded = {len(dataset)}.")
     dataloader = torch.utils.data.DataLoader(dataset, batch_size=len(dataset))
 
     # define upstream model
-    upstream_model = S3PRLUpstream(config["upstream"]).to(device)
+    upstream_model = get_upstream(config["upstream"]).to(device)
     upstream_model.eval()
     upstream_featurizer = Featurizer(upstream_model).to(device)
-    upstream_featurizer.load_state_dict(torch.load(args.checkpoint, map_location="cpu")["featurizer"])
+    upstream_featurizer.load_state_dict(
+        torch.load(args.checkpoint, map_location="cpu")["featurizer"]
+    )
     upstream_featurizer.eval()
 
     # get model and load parameters
@@ -189,17 +210,35 @@ def main():
             config["trg_stats"],
             device,
         )
+    else:
+        vocoder = Spectrogram2Waveform(
+            stats=config["trg_stats"],
+            n_fft=config["fft_size"],
+            n_shift=config["hop_size"],
+            fs=config["sampling_rate"],
+            n_mels=config["num_mels"],
+            fmin=config["fmin"],
+            fmax=config["fmax"],
+            griffin_lim_iters=64,
+        )
 
     # start generation
     with torch.no_grad():
-        for utt_id, x, mel in tqdm(dataset):
+        for batch in tqdm(dataset):
+            utt_id = batch["utt_id"]
+            x = batch["audio"]
+            mel = batch["mel"]
+            f0s = batch["f0"]
+
             xs = torch.from_numpy(x).unsqueeze(0).float().to(device)
+            if f0s is not None:
+                f0s = torch.from_numpy(f0s).unsqueeze(0).float().to(device)
             ilens = torch.LongTensor([x.shape[0]]).to(device)
 
             start_time = time.time()
             all_hs, all_hlens = upstream_model(xs, ilens)
             hs, hlens = upstream_featurizer(all_hs, all_hlens)
-            outs, _ = model(hs, hlens, spk_embs=None)
+            outs, _ = model(hs, hlens, spk_embs=None, f0s=f0s)
             out = outs[0]
             logging.info(
                 "inference speed = %.1f frames / sec."
