@@ -18,10 +18,11 @@ import yaml
 
 from tqdm import tqdm
 
-from s3prl.nn import S3PRLUpstream, Featurizer
+from s3prl.nn import Featurizer
 
 import s3prl_vc.models
-from s3prl_vc.datasets.datasets import AudioSCPMelDataset, AudioMelDataset
+from s3prl_vc.upstream.interface import get_upstream
+from s3prl_vc.datasets.datasets import AudioSCPMelDataset
 from s3prl_vc.utils import read_hdf5, write_hdf5
 from s3prl_vc.utils.data import pad_list
 from s3prl_vc.utils.plot import plot_generated_and_ref_2d, plot_1d
@@ -72,9 +73,7 @@ def main():
         "--feat_type",
         type=str,
         default="feats",
-        help=(
-            "feature type. this is used as key name to read h5 featyre files. "
-        ),
+        help=("feature type. this is used as key name to read h5 featyre files. "),
     )
     parser.add_argument(
         "--verbose",
@@ -139,21 +138,25 @@ def main():
             config,
             return_utt_id=True,
         )
-        
+
     logging.info(f"The number of files to be extracted = {len(dataset)}.")
     dataloader = torch.utils.data.DataLoader(dataset, batch_size=len(dataset))
 
     # define upstream model
-    upstream_model = S3PRLUpstream(config["upstream"]).to(device)
+    upstream_model = get_upstream(config["upstream"]).to(device)
     upstream_model.eval()
     upstream_featurizer = Featurizer(upstream_model).to(device)
-    upstream_featurizer.load_state_dict(torch.load(args.checkpoint, map_location="cpu")["featurizer"])
+    upstream_featurizer.load_state_dict(
+        torch.load(args.checkpoint, map_location="cpu")["featurizer"]
+    )
     upstream_featurizer.eval()
     logging.info(f"Loaded model parameters from {args.checkpoint}.")
 
     # start generation
     with torch.no_grad():
-        for utt_id, x, mel in tqdm(dataset):
+        for items in tqdm(dataset):
+            utt_id = items["utt_id"]
+            x = items["audio"]
             xs = torch.from_numpy(x).unsqueeze(0).float().to(device)
             ilens = torch.LongTensor([x.shape[0]]).to(device)
 
@@ -168,7 +171,9 @@ def main():
 
             # write feats
             if not os.path.exists(os.path.join(config["outdir"], args.feat_type)):
-                os.makedirs(os.path.join(config["outdir"], args.feat_type), exist_ok=True)
+                os.makedirs(
+                    os.path.join(config["outdir"], args.feat_type), exist_ok=True
+                )
 
             write_hdf5(
                 config["outdir"] + f"/{args.feat_type}/{utt_id}.h5",
@@ -176,5 +181,6 @@ def main():
                 h.cpu().numpy().astype(np.float32),
             )
 
+
 if __name__ == "__main__":
     main()
