@@ -1,6 +1,9 @@
 from torch.optim.lr_scheduler import LambdaLR
 
-def Linear_schedule_with_warmup(optimizer, num_warmup_steps, num_training_steps, last_epoch=-1):
+
+def Linear_schedule_with_warmup(
+    optimizer, num_warmup_steps, num_training_steps, last_epoch=-1
+):
     """
     Create a schedule with a learning rate that decreases linearly from the initial lr set in the optimizer to 0,
     after a warmup period during which it increases linearly from 0 to the initial lr set in the optimizer.
@@ -21,8 +24,9 @@ def Linear_schedule_with_warmup(optimizer, num_warmup_steps, num_training_steps,
         if current_step < num_warmup_steps:
             return float(current_step) / float(max(1, num_warmup_steps))
         return max(
-            0.0, float(num_training_steps - current_step) /
-            float(max(1, num_training_steps - num_warmup_steps))
+            0.0,
+            float(num_training_steps - current_step)
+            / float(max(1, num_training_steps - num_warmup_steps)),
         )
 
-    return LambdaLR(optimizer, lr_lambda, last_epoch)
\ No newline at end of file
+    return LambdaLR(optimizer, lr_lambda, last_epoch)
